@@ -1,8 +1,8 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2022-11-22 16:41:03
-:LastEditors: ChenXiaolei
+:LastEditTime: 2022-12-06 09:54:58
+:LastEditors: HuangJingCan
 :Description: StudioBaseHandler
 """
 
@@ -28,7 +28,7 @@ class StudioBaseHandler(BaseCookieHandler):
     :last_editors: HuangJingCan
     """
     def options_async(self):
-        self.reponse_json_success()
+        self.response_json_success()
 
     def check_xsrf_cookie(self):
         return
@@ -73,7 +73,7 @@ class StudioBaseHandler(BaseCookieHandler):
             rep_dic = rep_dic.__dict__
         return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder)
 
-    def reponse_custom(self, rep_dic):
+    def response_custom(self, rep_dic):
         """
         :description: 输出公共json模型
         :param rep_dic: 字典类型数据
@@ -82,7 +82,7 @@ class StudioBaseHandler(BaseCookieHandler):
         """
         self.http_reponse(self.json_dumps(rep_dic))
 
-    def reponse_common(self, result_code, result_message, data=None):
+    def response_common(self, result_code, result_message, data=None):
         """
         :description: 输出公共json模型
         :param result_code: 字符串，服务端返回的错误码
@@ -100,7 +100,7 @@ class StudioBaseHandler(BaseCookieHandler):
 
         self.http_reponse(self.json_dumps(rep_dic))
 
-    def reponse_json_success(self, data=None, desc='调用成功'):
+    def response_json_success(self, data=None, desc='调用成功'):
         """
         :description: 通用成功返回json结构
         :param data: 返回结果对象，即为数组，字典
@@ -108,25 +108,25 @@ class StudioBaseHandler(BaseCookieHandler):
         :return: 将dumps后的数据字符串返回给客户端
         :last_editors: HuangJingCan
         """
-        self.reponse_common("0", desc, data)
+        self.response_common("0", desc, data)
 
-    def reponse_json_error(self, desc='error'):
+    def response_json_error(self, desc='error'):
         """
         :description: 通用错误返回json结构
         :param desc: 字符串，服务端返回的错误信息
         :return: 将dumps后的数据字符串返回给客户端
         :last_editors: HuangJingCan
         """
-        self.reponse_common("1", desc)
+        self.response_common("1", desc)
 
-    def reponse_json_error_params(self, desc='params error'):
+    def response_json_error_params(self, desc='params error'):
         """
         :description: 参数错误返回json结构
         :param desc: 字符串，服务端返回的错误信息
         :return: 将dumps后的数据字符串返回给客户端
         :last_editors: HuangJingCan
         """
-        self.reponse_common("1", desc)
+        self.response_common("1", desc)
 
     def redis_init(self, db=None):
         """
@@ -426,92 +426,167 @@ class StudioBaseHandler(BaseCookieHandler):
                     setattr(s_model, filed, map_dict[filed])
         return s_model
 
+    def login_filter(self, is_need_login, optional_params):
+        """
+        :description: 登录过滤器
+        :param is_need_login: 是否需要登录（true需要false不需要）
+        :param optional_params: 其他参数
+        :return: InvokeResult
+        """
+        invoke_result = InvokeResult()
+        base_manage_context_key = config.get_value("base_manage_context_key")
+        # 获取头部信息
+        header_token = self.request_header_token()
+        user_id = header_token["UserID"] if header_token.__contains__("UserID") else ""
+        user_token = header_token["UserToken"] if header_token.__contains__("UserToken") else ""
+        user_id_md5 = header_token["UserIDMD5"] if header_token.__contains__("UserIDMD5") else ""
+        if user_id.strip() == "" or user_token.strip() == "" or user_id_md5.strip() == "":
+            # return self.response_common("NoLogin", "操作失败，用户未登录")
+            invoke_result.ResultCode = "error"
+            invoke_result.ResultMessage = "操作失败，用户未登录"
+            return invoke_result
+        if is_need_login and CryptoHelper.md5_encrypt(user_id, config.get_value("login_encrypt_key")) != user_id_md5:
+            # return self.response_common("NoLogin", "操作失败，用户未登录")
+            invoke_result.ResultCode = "error"
+            invoke_result.ResultMessage = "操作失败，用户未登录"
+            return invoke_result
+
+        # 登陆日志判断，Redis还是MySQL
+        if config.get_value("login_type") == "redis":
+            redis_user_login = self.redis_init().hget(config.get_value("redis_provider_name_user_login"), user_id)
+            user_login = {}
+            if redis_user_login:
+                user_login = json.loads(redis_user_login)
+
+            if not user_login or TimeHelper.format_time_to_datetime(user_login["ExpireTime"]) < TimeHelper.get_now_datetime():
+                if not is_need_login:
+                    return invoke_result
+                self.clear_cookie("UserID")
+                self.clear_cookie("UserIDMD5")
+                self.clear_cookie("UserToken")
+                # return self.response_common("UserExpire", "用户已过期，请重新登录")
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "用户已过期，请重新登录"
+                return invoke_result
+            if user_login["UserToken"] != user_token:
+                if not is_need_login:
+                    return invoke_result
+                self.clear_cookie("UserID")
+                self.clear_cookie("UserIDMD5")
+                self.clear_cookie("UserToken")
+                # return self.response_common("DeviceExpire", "用户在其他终端登录，请重新登录")
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "用户在其他终端登录，请重新登录"
+                return invoke_result
+
+            curr_user_info = UserInfoModel(config.get_value("manage_context_key")).get_entity_by_id(user_id)
+            if curr_user_info.IsLock == 1:
+                # return self.response_common("UserLimit", "用户已被锁，请联系管理员")
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "用户已被锁，请联系管理员"
+                return invoke_result
+
+            user_login["ExpireTime"] = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire"))
+            self.redis_init().hset(config.get_value("redis_provider_name_user_login"), user_id, self.json_dumps(user_login))
+        else:
+            user_login_model = UserLoginModel(base_manage_context_key)
+            user_login = user_login_model.get_entity_by_id(user_id)
+
+            if not user_login or TimeHelper.format_time_to_datetime(user_login.ExpireTime) < TimeHelper.get_now_datetime():
+                if not is_need_login:
+                    return invoke_result
+                self.clear_cookie("UserID")
+                self.clear_cookie("UserIDMD5")
+                self.clear_cookie("UserToken")
+                # return self.response_common("UserExpire", "用户已过期，请重新登录")
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "用户已过期，请重新登录"
+                return invoke_result
+            if user_login.UserToken != user_token:
+                if not is_need_login:
+                    return
+                self.clear_cookie("UserID")
+                self.clear_cookie("UserIDMD5")
+                self.clear_cookie("UserToken")
+                # return self.response_common("DeviceExpire", "用户在其他终端登录，请重新登录")
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "用户在其他终端登录，请重新登录"
+                return invoke_result
+
+            manage_context_key = self.get_manage_context_key()
+
+            curr_user_info = UserInfoModel(manage_context_key).get_entity_by_id(user_id)
+            if not curr_user_info:
+                # return self.response_common("UserNoExist", "用户不存在，请重新登录")
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "用户已过期，请重新登录"
+                return invoke_result
+            if curr_user_info.IsLock == 1:
+                # return self.response_common("UserLimit", "用户已被锁，请联系管理员")
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "用户已被锁，请联系管理员"
+                return invoke_result
+
+            if base_manage_context_key != manage_context_key:
+                curr_user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
+                if not curr_user_info:
+                    # return self.response_common("UserNoExist", "用户不存在，请重新登录")
+                    invoke_result.ResultCode = "error"
+                    invoke_result.ResultMessage = "用户已过期，请重新登录"
+                    return invoke_result
+                if curr_user_info.IsLock == 1:
+                    # return self.response_common("UserLimit", "用户已被锁，请联系管理员")
+                    invoke_result.ResultCode = "error"
+                    invoke_result.ResultMessage = "用户已被锁，请联系管理员"
+                    return invoke_result
+
+            user_login.ExpireTime = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire"))
+            user_login_model.update_table(f"ExpireTime='{user_login.ExpireTime}'", "UserID=%s", user_login.UserID)
+
+        return invoke_result
+
+    def power_filter(self, is_check_power, optional_params):
+        """
+        :description: 权限过滤器
+        :param is_check_power: 是否需要验证权限（true需要false不需要）
+        :param optional_params: 其他参数
+        :return: InvokeResult
+        """
+        invoke_result = InvokeResult()
+        user_info = self.get_curr_user_info()
+        base_user_info = self.get_base_user_info()
+        if not user_info or not base_user_info:
+            invoke_result.ResultCode = "error"
+            invoke_result.ResultMessage = "用户已过期，请重新登录"
+            return invoke_result
+        if is_check_power and user_info.IsSuper != 1 and base_user_info.IsSuper != 1:
+            api_path = self.request.path
+            if api_path.strip() == "":
+                # return self.response_common("NoPower", "没有权限")
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "该用户没有权限，请联系管理员"
+                return invoke_result
+            page_id = self.request_manage_page_id()
+            cote_id = page_id.split("$")[1] if page_id.__contains__("$") else ""
+            if not self.check_power_menu(api_path, cote_id):
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "该用户没有权限，请联系管理员"
+                return invoke_result
+        return invoke_result
+
 
 def login_filter(is_need_login=True, optional_params=None):
     """
     :description: 登陆过滤装饰器 仅限handler使用
-    :param is_need_login：是否需要登陆
+    :param is_need_login：是否需要登陆（true需要false不需要）
     :param optional_params：其他参数
     :return: handler
     """
     def check_login(handler):
         def wrapper(self, **args):
-            base_manage_context_key = config.get_value("base_manage_context_key")
-            # 获取头部信息
-            header_token = self.request_header_token()
-            user_id = header_token["UserID"] if header_token.__contains__("UserID") else ""
-            user_token = header_token["UserToken"] if header_token.__contains__("UserToken") else ""
-            user_id_md5 = header_token["UserIDMD5"] if header_token.__contains__("UserIDMD5") else ""
-            if user_id.strip() == "" or user_token.strip() == "" or user_id_md5.strip() == "":
-                return self.reponse_common("NoLogin", "未登录")
-            if is_need_login and CryptoHelper.md5_encrypt(user_id, config.get_value("login_encrypt_key")) != user_id_md5:
-                return self.reponse_common("NoLogin", "未登录")
-
-            # 登陆日志判断，Redis还是MySQL
-            if config.get_value("login_type") == "redis":
-                redis_user_login = self.redis_init().hget(config.get_value("redis_provider_name_user_login"), user_id)
-                user_login = {}
-                if redis_user_login:
-                    user_login = json.loads(redis_user_login)
-
-                if not user_login or TimeHelper.format_time_to_datetime(user_login["ExpireTime"]) < TimeHelper.get_now_datetime():
-                    if not is_need_login:
-                        return
-                    self.clear_cookie("UserID")
-                    self.clear_cookie("UserIDMD5")
-                    self.clear_cookie("UserToken")
-                    return self.reponse_common("UserExpire", "用户已过期，请重新登录")
-                if user_login["UserToken"] != user_token:
-                    if not is_need_login:
-                        return
-                    self.clear_cookie("UserID")
-                    self.clear_cookie("UserIDMD5")
-                    self.clear_cookie("UserToken")
-                    return self.reponse_common("DeviceExpire", "用户在其他终端登录")
-
-                curr_user_info = UserInfoModel(config.get_value("manage_context_key")).get_entity_by_id(user_id)
-                if curr_user_info.IsLock == 1:
-                    return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")
-
-                user_login["ExpireTime"] = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire"))
-                self.redis_init().hset(config.get_value("redis_provider_name_user_login"), user_id, self.json_dumps(user_login))
-            else:
-                user_login_model = UserLoginModel(base_manage_context_key)
-                user_login = user_login_model.get_entity_by_id(user_id)
-
-                if not user_login or TimeHelper.format_time_to_datetime(user_login.ExpireTime) < TimeHelper.get_now_datetime():
-                    if not is_need_login:
-                        return
-                    self.clear_cookie("UserID")
-                    self.clear_cookie("UserIDMD5")
-                    self.clear_cookie("UserToken")
-                    return self.reponse_common("UserExpire", "用户已过期，请重新登录")
-                if user_login.UserToken != user_token:
-                    if not is_need_login:
-                        return
-                    self.clear_cookie("UserID")
-                    self.clear_cookie("UserIDMD5")
-                    self.clear_cookie("UserToken")
-                    return self.reponse_common("DeviceExpire", "用户在其他终端登录")
-
-                manage_context_key = self.get_manage_context_key()
-
-                curr_user_info = UserInfoModel(manage_context_key).get_entity_by_id(user_id)
-                if not curr_user_info:
-                    return self.reponse_common("UserNoExist", "用户不存在，请重新登录")
-                if curr_user_info.IsLock == 1:
-                    return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")
-
-                if base_manage_context_key != manage_context_key:
-                    curr_user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
-                    if not curr_user_info:
-                        return self.reponse_common("UserNoExist", "用户不存在，请重新登录")
-                    if curr_user_info.IsLock == 1:
-                        return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")
-
-                user_login.ExpireTime = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire"))
-                user_login_model.update_table(f"ExpireTime='{user_login.ExpireTime}'", "UserID=%s", user_login.UserID)
-
+            invoke_result = self.login_filter(is_need_login, optional_params)
+            if invoke_result.ResultCode != "0":
+                return self.response_common(invoke_result.ResultCode, invoke_result.ResultMessage)
             return handler(self, **args)
 
         return wrapper
@@ -521,21 +596,16 @@ def login_filter(is_need_login=True, optional_params=None):
 
 def power_filter(is_check_power=True, optional_params=None):
     """ 
-    权限过滤装饰器 仅限handler使用 
+    :description: 权限过滤装饰器 仅限handler使用
+    :param is_check_power: 是否需要验证权限（true需要false不需要）
+    :param optional_params: 其他参数
+    :return: handler
     """
     def check_power(handler):
         def wrapper(self, **args):
-            user_info = self.get_curr_user_info()
-            base_user_info = self.get_base_user_info()
-            if user_info and base_user_info:
-                if is_check_power and user_info.IsSuper != 1 and base_user_info.IsSuper != 1:
-                    api_path = self.request.path
-                    if api_path.strip() == "":
-                        return self.reponse_common("NoPower", "没有权限")
-                    page_id = self.request_manage_page_id()
-                    cote_id = page_id.split("$")[1] if page_id.__contains__("$") else ""
-                    if not self.check_power_menu(api_path, cote_id):
-                        return self.reponse_common("NoPower", "没有权限")
+            invoke_result = self.power_filter(is_check_power, optional_params)
+            if invoke_result.ResultCode != "0":
+                return self.response_common(invoke_result.ResultCode, invoke_result.ResultMessage)
 
             return handler(self, **args)
 
