@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-22 14:32:40
-:LastEditTime: 2021-01-12 08:36:04
+:LastEditTime: 2022-12-06 17:39:26
 :LastEditors: HuangJingCan
 :Description: 栏目扩展类
 """
@@ -107,7 +107,7 @@ class MenuInfoModelEx(MenuInfoModel):
                 curr_menu_info.CommandName = "create"
                 curr_menu_info.MenuName = "新增"
                 curr_menu_info.MenuIcon = "plus-circle"
-            elif curr_button_type_enum == ButtonPlace.List.value:
+            elif curr_button_type_enum == ButtonType.Delete.value:
                 curr_menu_info.ButtonPlace = ButtonPlace.List.value
                 curr_menu_info.CommandName = "delete"
                 curr_menu_info.MenuName = "删除"
@@ -131,7 +131,7 @@ class MenuInfoModelEx(MenuInfoModel):
             elif curr_button_type_enum == ButtonType.View.value:
                 curr_menu_info.ButtonPlace = ButtonPlace.List.value
                 curr_menu_info.CommandName = "view"
-                curr_menu_info.MenuName = "查看详细"
+                curr_menu_info.MenuName = "查看"
                 curr_menu_info.ButtonColor = "info"
             elif curr_button_type_enum == ButtonType.Release.value:
                 curr_menu_info.ButtonPlace = ButtonPlace.List.value
@@ -224,16 +224,47 @@ class MenuInfoModelEx(MenuInfoModel):
         :return: 
         :last_editors: HuangJingCan
         """
+        invoke_result = InvokeResult()
+
         menu_info_list = self.get_list(f"IDPath LIKE '%{copy_menu_id}%'")
-        if menu_info_list:
-            copy_menu_info = [i for i in menu_info_list if i.MenuID == copy_menu_id][0]
-            copy_menu_info.MenuType = 2 if copy_menu_info.MenuType == 1 else copy_menu_info.MenuType
-            copy_menu_info.MenuID = UUIDHelper.get_uuid()
-            copy_menu_info.MenuName += "==复制"
-            copy_menu_info.ParentID = stick_menu_id
-            copy_menu_info.SortIndex = 0
-            self.add(copy_menu_info)
-            self.add_copy_child_menu(copy_menu_id, copy_menu_info.MenuID, menu_info_list)
+        if not menu_info_list:
+            invoke_result.ResultCode = "error"
+            invoke_result.ResultMessage = "操作失败，没有需要复制的栏目"
+            return invoke_result
+
+        sub_menu_list = [i for i in menu_info_list if i.MenuID != copy_menu_id]
+        copy_menu_info = [i for i in menu_info_list if i.MenuID == copy_menu_id][0]
+        copy_menu_info.MenuType = 2 if copy_menu_info.MenuType == 1 else copy_menu_info.MenuType
+        copy_menu_info.MenuID = UUIDHelper.get_uuid()
+        copy_menu_info.MenuName += "==复制"
+        copy_menu_info.ParentID = stick_menu_id
+        copy_menu_info.SortIndex += 1
+        # 获取父节点信息
+        stick_menu = self.get_entity_by_id(stick_menu_id)
+        if not stick_menu:
+            invoke_result.ResultCode = "error"
+            invoke_result.ResultMessage = "操作失败，没有需要复制的栏目"
+            return invoke_result
+        # 无法拷贝到操作菜单下
+        if stick_menu.MenuType == 3:
+            invoke_result.ResultCode = "error"
+            invoke_result.ResultMessage = "操作失败，无法拷贝到操作菜单下"
+            return invoke_result
+        # 不能拷贝到子节点下
+        if copy_menu_info.Depth < stick_menu.Depth:
+            is_sub_menu = [i for i in sub_menu_list if i.IDPath.__contains__(stick_menu_id)]
+            if is_sub_menu:
+                invoke_result.ResultCode = "error"
+                invoke_result.ResultMessage = "操作失败，无法拷贝到子节点下"
+                return invoke_result
+        copy_menu_info.IDPath = stick_menu.IDPath + copy_menu_info.MenuID + ","
+        copy_menu_info.MenuNamePath = stick_menu.MenuNamePath + copy_menu_info.MenuName + ","
+        copy_menu_info.Depth = stick_menu.Depth + 1
+
+        self.add_entity(copy_menu_info)
+        self.add_copy_child_menu(copy_menu_id, copy_menu_info.MenuID, sub_menu_list)
+
+        return invoke_result
 
     def add_copy_child_menu(self, old_parent_id, curr_parent_id, menu_info_list):
         """
@@ -247,9 +278,14 @@ class MenuInfoModelEx(MenuInfoModel):
             curr_menu_id = curr_menu_info.MenuID
             curr_menu_info.MenuID = UUIDHelper.get_uuid()
             curr_menu_info.ParentID = curr_parent_id
-            curr_menu_info.SortIndex = 0
-            self.add(curr_menu_info)
-            self.add_copy_child_menu(curr_menu_id, curr_menu_info.MenuID, [i for i in menu_info_list if i.ParentID == old_parent_id])
+            # 获取父节点信息
+            parent_menu = self.get_entity_by_id(curr_parent_id)
+            if parent_menu:
+                curr_menu_info.IDPath = parent_menu.IDPath + curr_menu_info.MenuID + ","
+                curr_menu_info.MenuNamePath = parent_menu.MenuNamePath + curr_menu_info.MenuName + ","
+                curr_menu_info.Depth = parent_menu.Depth + 1
+            self.add_entity(curr_menu_info)
+            self.add_copy_child_menu(curr_menu_id, curr_menu_info.MenuID, menu_info_list)
 
     def update_move(self, move_id, target_id):
         """
@@ -393,4 +429,20 @@ class MenuInfoModelEx(MenuInfoModel):
         count = self.del_entity("IDPath like '" + menu_info.IDPath + "%'")
         have_child = 1 if self.get_total("ParentID=%s", params=[menu_info.ParentID]) > 0 else 0
         self.update_table("HaveChild=%s", "ParentID=%s", [have_child, menu_info.ParentID])
-        return count
\ No newline at end of file
+        return count
+
+    def clear_menu(self, parent_id=""):
+        """
+        :description: 清理栏目
+        :param parent_id: 父栏目id
+        :return 
+        :last_editors: HuangJingCan
+        """
+        menu_list = self.get_list("ParentID=%s", params=[parent_id])
+        for menu in menu_list:
+            have_child = 1 if self.get_total("ParentID=%s", params=[menu.MenuID]) > 0 else 0
+            menu.HaveChild = have_child
+
+            MenuInfoModelEx(sub_table="copy").add_entity(menu)
+
+            self.clear_menu(menu.MenuID)
\ No newline at end of file
